.. automodule:: xclim.indicators.atmos
   :members:
   :undoc-members:
   :imported-members:

.. automodule:: xclim.indicators.land
   :members:
   :undoc-members:
   :imported-members:

.. automodule:: xclim.indicators.seaIce
   :members:
   :undoc-members:
   :imported-members:

============================
Virtual indicator submodules
============================

.. automodule:: xclim.indicators.cf
   :members:
   :imported-members:
   :undoc-members:

.. automodule:: xclim.indicators.icclim
   :members:
   :imported-members:
   :undoc-members:

.. automodule:: xclim.indicators.anuclim
   :members:
   :imported-members:
   :undoc-members:
